#include "drawlabel.h"
#include <qdebug.h>

DrawLabel::DrawLabel(QWidget *parent) : QLabel(parent)
{
    lines = new QLine[100];
    count = 0;
}


DrawLabel::~DrawLabel()
{
    delete lines;
}

void DrawLabel::paintEvent(QPaintEvent *)
{
    QPainter paint(this);
//    qDebug() << "update" << endl;
    QMatrix m;
    QLine invertedLine;
    QPoint point;
    paint.eraseRect(10,10,PLOT_WIDTH + 10,PLOT_HEIGHT+10);

    paint.setPen(QColor(Qt::black));
    QPoint transOffs = QPoint(PLOT_WIDTH+10,PLOT_HEIGHT+10);
    paint.translate(transOffs);
    paint.scale(3.0,2.0);

    // draw the axis
    // horizontal
    paint.drawLine(-100,0,100,0);
    for (int i=1; i<10; i++)
        paint.drawLine(20*i-100,-2,20*i-100,2);
// vertical
    paint.drawLine(0,-100,0,100);
    for (int i=1; i<10; i++)
        paint.drawLine(-2,20*i-100,2,20*i-100);

    paint.setPen(QColor(Qt::blue));
    //    paint.drawRect(-10,-10,20,20);
    for (int i=0; i<count;i++) {
        point = QPoint(lines[i].x1(),-lines[i].y1());
        invertedLine.setP1(point);
        point = QPoint(lines[i].x2(),-lines[i].y2());
        invertedLine.setP2(point);
        paint.drawLine(invertedLine);
//        qDebug() << "Draw Line x1 y1 x2 y2" << lines[i].x1()<<" " << lines[i].y1()<<
//                " " << lines[i].x2() << " " << lines[i].y2() << endl;
    }
    paint.setPen(QColor(Qt::red));
    if (enableEllipse) {
        m.rotate(angle);
        paint.setMatrix(m,true);
        paint.drawEllipse(ellipseRect);
//        qDebug() << "Draw Ellipse x width" << ellipseRect.x()<<" " << ellipseRect.width()<< endl;
//        qDebug() << "Draw Ellipse y height" << ellipseRect.y()<<" " << ellipseRect.height()<< endl;
    }
}
void DrawLabel::draw(QLine line)
{

    lines[count] = clip(line);
    count++;

    QLine parallel;
    QPoint point = QPoint(-line.x1(),-line.y1());
    parallel.setP1(point);
    point = QPoint(-line.x2(),-line.y2());
    parallel.setP2(point);
    lines[count] = clip(parallel);
    count++;

    update();
    qDebug() << "count: " << count << endl;
}

void DrawLabel::drawEllipse(QRect rect)
{
    ellipseRect = rect;
}

QLine DrawLabel::clip(QLine line)
{
    double a,b,x1,y1,x2,y2;
    QLine clippedLine;

    x1 = (double)line.x1();
    x2 = (double)line.x2();
    y1 = (double)line.y1();
    y2 = (double)line.y2();

    if (x1 == x2)
    {
        y1 = -PLOT_HEIGHT;
        y2 =  PLOT_HEIGHT;
    }
    else {
        a = (y2-y1)/(x2-x1);
        b = y1 - a*x1;

        x1 = -100.0;
        y1 = -100.0*a + b;

        if (y1 < -100.0) {
            y1 = -100.0;
            x1 = (y1-b)/a;
        }
            qDebug() << a << b << endl;

        if (y1 > 100.0) {
            y1 = 100.0;
            x1 = (y1-b)/a;
        }
        x2 = 100.0;
        y2 = x2 *a + b;
        if (y2 < -100.0) {
            y2 = -100.0;
            x2 = (y2-b)/a;
        }
        if (y2 > 100.0)  {
            y2 = 100.0;
            x2 = (y2-b)/a;
        }
    }
    QPoint point = QPoint((int)x1,(int)y1);
    clippedLine.setP1(point);
    point = QPoint((int)x2,(int)y2);
    clippedLine.setP2(point);
    qDebug() << " x1,y1,x2,y2 " <<x1<<","<<y1<<","<<x2<<","<<y2<<endl;
    return clippedLine;

}
